Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(932)

Unified Diff: pkg/front_end/lib/src/fasta/target.dart

Issue 2893563003: Rename buildOutline() and separate 'build' and 'writeProgram()'. (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/front_end/lib/src/fasta/target.dart
diff --git a/pkg/front_end/lib/src/fasta/target.dart b/pkg/front_end/lib/src/fasta/target.dart
index 88b817e731bdae778312010c847281417a4835f4..c49da710b081550db85a26aaf463c32b5bad5c09 100644
--- a/pkg/front_end/lib/src/fasta/target.dart
+++ b/pkg/front_end/lib/src/fasta/target.dart
@@ -6,12 +6,14 @@ library fasta.target;
import 'dart:async' show Future;
+import 'package:kernel/ast.dart';
import 'ticker.dart' show Ticker;
/// A compilation target.
///
/// A target reads source files with [read] and computes outlines when
/// [computeOutline] is called.
abstract class Target {
final Ticker ticker;
@@ -20,9 +22,9 @@ abstract class Target {
/// Instructs this target to include [uri] in its result.
void read(Uri uri);
- /// Compute outlines for all [read] URIs.
- Future<Null> computeOutline();
+ /// Build and return outlines for all libraries.
+ Future<Program> buildOutlines();
- /// Write the resulting program in the file [uri].
- Future writeProgram(Uri uri);
+ /// Build and return the full program for all libraries.
+ Future<Program> buildProgram();
}
« no previous file with comments | « pkg/front_end/lib/src/fasta/kernel/kernel_target.dart ('k') | pkg/front_end/lib/src/incremental_kernel_generator_impl.dart » ('j') | no next file with comments »
@@ -6,12 +6,14 @@ library fasta.target;
/// A compilation target.
///
-/// A target reads source files with [read] and computes outlines when
-/// [computeOutline] is called.
+/// A target reads source files with [read], builds outlines when
+/// [buildOutlines] is called and builds the full program when [buildProgram]
+/// is called.
abstract class Target {
final Ticker ticker;

Powered by Google App Engine
This is Rietveld 408576698